@@ -187,6 +187,7 @@ class UMF_Message:
                 else:
                     instance = sub_id[0]
                     sub_id = ''
+                service_name = sub_segments[1]
         x = re.search(r'\[(.*?)\]', segments[1])
         if x and x.group(1):
             http_method = x.group(1)
@@ -327,6 +328,27 @@ class HydraPy:
                 instance = instances_list[0]['instanceID']
             await self._redis.publish(f"{self._mc_message_key}:{parsed_route['service_name']}:{instance}", json.dumps(umf_message))
 
+    async def send_message_reply(self, src_message, reply_message):
+        msg = None
+        if 'via' in src_message:
+            parsed_route = UMF_Message.parse_route(src_message['via'])
+            msg = (UMF_Message()).create_message({
+                'to': src_message['via'],
+                'from': src_message['to'],
+                'via': src_message['via'],
+                'rmid': src_message['mid'],
+                'body': reply_message['body']
+            })
+        else:
+            parsed_route = UMF_Message.parse_route(src_message['from'])
+            msg = (UMF_Message()).create_message({
+                'to': src_message['from'],
+                'from': src_message['to'],
+                'rmid': src_message['mid'],
+                'body': reply_message['body']
+            })
+        await self.hydra.send_message(msg)
+
     async def send_broadcast_message(self, umf_message):
         parsed_route = UMF_Message.parse_route(umf_message['to'])
         key = f"{self._mc_message_key}:{parsed_route['service_name']}"
@@ -341,7 +363,6 @@ class HydraPy:
             ids.append(keys)
         trans=[]
         tr = self._redis.multi_exec()
-        pp(ids)
         for entries in ids:
             for entry in entries:
                 if len(entry) != 0:
@@ -447,12 +468,12 @@ class HydraPy:
             'version': self._service_version,
             'instanceID': self._instance_id,
             'severity': severity,
-            'body': {}
+            'bdy': {}
         }
         if text:
             new_entry['message'] = text
         if entry:
-            new_entry['body'] = entry
+            new_entry['bdy'] = entry
         await self.send_broadcast_message((UMF_Message()).create_message({
             'to': 'hydra-logging-svcs:/',
             'from': f'{self._service_name}:/',
@@ -492,3 +513,6 @@ class HydraPy:
         # await self._redis.wait_closed()
 
         return self.get_service_info()
+
+    async def run(self):
+        await self._redis.wait_closed()
